@@ -3,8 +3,7 @@ package Text::Xslate::PP;
 use 5.008_001;
 use strict;
 
-our $VERSION = '1.0012';
-$VERSION =~ s/_//; # for developpers versions
+our $VERSION = '1.1000';
 
 BEGIN{
     $ENV{XSLATE} = ($ENV{XSLATE} || '') . '[pp]';
@@ -14,11 +13,6 @@ use Text::Xslate::Util qw(
     p
 );
 
-use constant _PP_OPCODE  => scalar($DEBUG =~ /\b pp=opcode  \b/xms);
-use constant _PP_BOOSTER => scalar($DEBUG =~ /\b pp=booster \b/xms);
-use constant _PP_BACKEND =>   _PP_OPCODE  ? 'Opcode'
-                            : _PP_BOOSTER ? 'Booster'
-                            :               'Opcode'; # default
 use constant _PP_ERROR_VERBOSE => scalar($DEBUG =~ /\b pp=verbose \b/xms);
 
 use constant _DUMP_LOAD => scalar($DEBUG =~ /\b dump=load \b/xms);
@@ -26,16 +20,17 @@ use constant _DUMP_LOAD => scalar($DEBUG =~ /\b dump=load \b/xms);
 use Text::Xslate::PP::Const qw(:all);
 use Text::Xslate::PP::State;
 use Text::Xslate::PP::Type::Raw;
+use Text::Xslate::PP::Opcode;
 use Text::Xslate ();
 
 use Scalar::Util ();
 use overload     ();
 use Carp         ();
 
-require sprintf('Text/Xslate/PP/%s.pm', _PP_BACKEND);
 
-my $state_class = 'Text::Xslate::PP::' . _PP_BACKEND;
-$state_class->VERSION($VERSION); # ensure the version
+my $state_class = 'Text::Xslate::PP::Opcode';
+
+$VERSION =~ s/_//; # for developpers versions
 
 if(_PP_ERROR_VERBOSE) {
     Carp->import('verbose');
@@ -69,12 +64,6 @@ our %html_escape = (
 );
 our $html_metachars = sprintf '[%s]', join '', map { quotemeta } keys %html_escape;
 
-sub options {
-    my $options  = Text::Xslate::Engine->options;
-    $options->{ compiler } = 'Text::Xslate::' . (_PP_BACKEND eq 'Booster' ? 'PP::Compiler' : 'Compiler');
-    return $options;
-}
-
 #
 # public APIs
 #
@@ -158,16 +147,6 @@ sub _assemble {
 
     my $st  = $state_class->new();
 
-    if(_PP_BACKEND eq 'Booster'){
-        if($asm->[0][0] eq '_ppbooster') {
-            my $ppbooster = shift @{$asm};
-            $st->{ booster_code } = Text::Xslate::PP::Booster->compile($ppbooster->[1]);
-        }
-        else {
-            Carp::croak("Oops: No booster code: ", p($asm));
-        }
-    }
-
     $st->symbol({ %{$self->{ function }} });
 
     my $tmpl = [];
@@ -230,9 +209,7 @@ sub _assemble {
             file   => $oi_file,
         };
 
-        if(_PP_BACKEND eq 'Opcode') {
-            $code->[ $i ]->{ exec_code } = $OPCODE[ $opnum ];
-        }
+        $code->[ $i ]->{ exec_code } = $OPCODE[ $opnum ];
 
         my $oparg = $OPARGS[ $opnum ];
 
@@ -377,9 +354,6 @@ sub tx_check_itr_ar {
             "Iterator variables must be an ARRAY reference, not %s",
             Text::Xslate::Util::neat( $ar ) );
     }
-    else {
-        $st->warn( [$frame, $line], "Use of nil to iterate" );
-    }
     return [];
 }
 
@@ -565,6 +539,10 @@ sub tx_execute {
     if ( $_depth > 100 ) {
         Carp::croak("Execution is too deep (> 100)");
     }
+    if(_PP_ERROR_VERBOSE and ref $st->{code}->[0]->{ exec_code } ne 'CODE') {
+        Carp::croak("Oops: Not a CODE reference: "
+            . Text::Xslate::Util::neat($st->{code}->[0]->{ exec_code }));
+    }
 
     local $st->{pc}   = 0;
     local $st->{vars} = $vars;
@@ -575,25 +553,11 @@ sub tx_execute {
     local $st->{local_stack};
     local $st->{SP} = [];
 
-    if ( _PP_BACKEND eq 'Booster' ) {
-        if(_PP_ERROR_VERBOSE and ref $st->{ booster_code } ne 'CODE') {
-            Carp::croak("Oops: Not a CODE reference: "
-                . Text::Xslate::Util::neat($st->{ booster_code }));
-        }
-        return $st->{ booster_code }->( $st );
-    }
-    else {
-        if(_PP_ERROR_VERBOSE and ref $st->{code}->[0]->{ exec_code } ne 'CODE') {
-            Carp::croak("Oops: Not a CODE reference: "
-                . Text::Xslate::Util::neat($st->{code}->[0]->{ exec_code }));
-        }
-
-        local $st->{sa};
-        local $st->{sb};
-        local $st->{output} = '';
-        $st->{code}->[0]->{ exec_code }->( $st );
-        return $st->{output};
-    }
+    local $st->{sa};
+    local $st->{sb};
+    local $st->{output} = '';
+    $st->{code}->[0]->{ exec_code }->( $st );
+    return $st->{output};
 }
 
 
@@ -667,11 +631,11 @@ Text::Xslate::PP - Yet another Text::Xslate runtime in pure Perl
 
 =head1 VERSION
 
-This document describes Text::Xslate::PP version 1.0012.
+This document describes Text::Xslate::PP version 1.1000.
 
 =head1 DESCRIPTION
 
-This module implements Text::Xslate runtime engine in pure Perl.
+This module implements a Text::Xslate runtime engine in pure Perl.
 Normally it will be loaded if it fails to load XS. So you do not need
 to use this module explicitly.
 
@@ -686,58 +650,14 @@ If you want to use Text::Xslate::PP, however, you can use it.
 
 XS/PP mode might be switched with C<< $ENV{XSLATE} = 'pp' or 'xs' >>.
 
-From 0.1024 on, there are two pure Perl engines.
-C<Text::Xslate::PP::Booster>, enabled by C<< $ENV{XSLATE} = 'pp=booster' >>,
-generates optimized Perl code from intermediate code.
-C<Text::Xslate::PP::Opcode>, enabled by C<< $ENV{XSLATE} = 'pp=opcode' >>,
-executes intermediate code directly, emulating the virtual machine in pure Perl.
-
-PP::Booster is much faster than PP::Opcode, but it may be less stable.
-The default pure Perl engine is B<PP::Booster>, so if you run into problems,
-please try C<< $ENV{XSLATE} = 'pp=opcode' >>.
-
 C<< $ENV{XSLATE} = 'pp=verbose' } >> may be useful for debugging.
 
-=head1 NOTE
-
-=head2 Performance
-
-There might be cases where you cannot use XS modules.
-
-Here is a result of F<benchmark/x-poor-env.pl> to compare pure Perl template
-engines in poor environment where applications runs as CGI scripts and XS
-modules are not available.
-
-    $ perl -Mblib benchmark/x-poor-env.pl
-    Perl/5.10.1 i686-linux
-    Xslate backend: Booster
-    Text::Xslate/0.1058
-    Template/2.22
-    HTML::Template/2.9
-    Text::MicroTemplate/0.15
-    Text::MicroTemplate::Extended/0.11
-    1..3
-    ok 1 - TT: Template-Toolkit
-    ok 2 - MT: Text::MicroTemplate
-    ok 3 - HT: HTML::Template
-    Benchmarks with 'include' (datasize=100)
-             Rate     TT     HT Xslate     MT
-    TT     76.1/s     --   -60%   -61%   -82%
-    HT      189/s   149%     --    -3%   -56%
-    Xslate  196/s   158%     4%     --   -54%
-    MT      429/s   463%   126%   118%     --
-
-According to this result, PP::Booster is over 2 times faster than Template::Toolkit,
-and as fast as HTML::Template, but slower than Text::MicroTemplate.
-
 =head1 SEE ALSO
 
 L<Text::Xslate>
 
 L<Text::Xslate::PP::Opcode>
 
-L<Text::Xslate::PP::Booster>
-
 =head1 AUTHOR
 
 Text::Xslate::PP stuff is originally written by Makamaka Hannyaharamitu
