@@ -63,6 +63,9 @@ sub init_symbols {
     $parser->symbol('DEFAULT') ->set_std(\&std_set);
     $parser->symbol('CALL')    ->set_std(\&std_call);
 
+    $parser->symbol('NEXT')    ->set_std( $parser->can('std_next') );
+    $parser->symbol('LAST')    ->set_std( $parser->can('std_last') );
+
     $parser->symbol('MACRO') ->set_std(\&std_macro);
     $parser->symbol('BLOCK');
     $parser->symbol('WRAPPER')->set_std(\&std_wrapper);
@@ -73,7 +76,7 @@ sub init_symbols {
     # unsupported directives
     my $nos = $parser->can('not_supported');
     foreach my $keyword (qw(
-            INSERT PROCESS PERL RAWPERL TRY THROW NEXT LAST RETURN
+            INSERT PROCESS PERL RAWPERL TRY THROW RETURN
             STOP CLEAR META TAGS DEBUG VIEW)) {
         $parser->symbol($keyword)->set_std($nos);
     }
@@ -660,6 +663,14 @@ discouraged because they are not easy to understand:
     loop.first # for loop.is_first
     loop.last  # for loop.is_last
 
+Loop control statements, namely C<NEXT> and C<LAST>, are also supported
+in both C<FOR> and C<WHILE> loops.
+
+    [% FOR item IN data -%]
+        [% LAST IF item == 42 -%]
+        ...
+    [% END -%]
+
 =head2 Conditional statements
 
     [% IF logical_expression %]
@@ -868,7 +879,7 @@ plugins which do not depend on the context object of Template-Toolkit.
 
 The following directives are not supported:
 C<INSERT>, C<PROCESS>, C<BLOCK> as a named blocks, C<USE> (but see above),
-C<PERL>, C<RAWPERL>, C<TRY>, C<THROW>, C<NEXT>, C<LAST>,
+C<PERL>, C<RAWPERL>, C<TRY>, C<THROW>,
 C<RETURN>, C<STOP>, C<CLEAR>, C<META>, C<TAGS>, C<DEBUG>, and C<VIEW>.
 
 Some might be supported in a future.
